@@ -301,7 +301,7 @@ fn warn_uv_toml_masked_fields(options: &Options) {
                 allow_insecure_host,
             },
         top_level:
-            ResolverInstallerOptions {
+            ResolverInstallerSchema {
                 index,
                 index_url,
                 extra_index_url,
@@ -318,6 +318,7 @@ fn warn_uv_toml_masked_fields(options: &Options) {
                 no_build_isolation,
                 no_build_isolation_package,
                 extra_build_dependencies,
+                extra_build_variables,
                 exclude_newer,
                 exclude_newer_package,
                 link_mode,
@@ -449,6 +450,9 @@ fn warn_uv_toml_masked_fields(options: &Options) {
     if extra_build_dependencies.is_some() {
         masked_fields.push("extra-build-dependencies");
     }
+    if extra_build_variables.is_some() {
+        masked_fields.push("extra-build-variables");
+    }
     if exclude_newer.is_some() {
         masked_fields.push("exclude-newer");
     }
